@@ -612,7 +612,10 @@ class CleanSummary(RoborockBase):
     last_clean_t: int | None = None
 
     def __post_init__(self) -> None:
-        self.square_meter_clean_area = round(self.clean_area / 1000000, 1) if self.clean_area is not None else None
+        if isinstance(self.clean_area, list):
+            _LOGGER.warning(f"Clean area is a unexpected type! Please give the following in a issue: {self.clean_area}")
+        else:
+            self.square_meter_clean_area = round(self.clean_area / 1000000, 1) if self.clean_area is not None else None
 
 
 @dataclass
